JUST A SIMPLE PACKAGE

A style of damg team object, I modified a bit base on PyQt5.

DAMG: just an object.

DAMGERROR: An exception type object.

DAMGLIST: An list type object.

DAMGDICT: An dict type object.

DAMGWORKER: Using QRunable for multi threading.

DAMGTHREAD: Using QThread for multi threading.

DAMGTHREADPOOL: A thread pool to manage multi threading

Enjoy.